filters

package
v0.0.0-...-6487655 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2021 License: Unlicense Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var FilterFolder string

FilterFolder is the folder that filters are saved/loaded from

var Filters map[string]string

Filters maps reywords to result maps

var OutputLocation string

OutputLocation is the folder that compiled filters get saved to

Functions

func CompileAll

func CompileAll()

CompileAll builds every filter you have

func CompileFilter

func CompileFilter(name string)

CompileFilter processes substitutions and builds the result filter

func DeleteFilter

func DeleteFilter(name string)

DeleteFilter deletes the filter file with this name

func GetFilterKeys

func GetFilterKeys() []string

GetFilterKeys retrieves the keys from the Filters map and returns them as an array

func LoadFilters

func LoadFilters(folderLocation string, outputLocation string)

LoadFilters loads filter files from the specified folder location

func SaveFilter

func SaveFilter(name string, content string)

SaveFilter saves the content as a filter file with name {name}.rep

Types

This section is empty.

Jump to